@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+    # -*- coding: utf-8 -*-
 """ Stanley Flat File Blog Tool
     ---------------------------
     author: Glen Swinfield <glen.swinfied@gmail.com>
@@ -11,25 +11,6 @@ import markdown
 from datetime import datetime
 
 
-def create_content(parser, paths):
-    full_path = paths.get('full_path')
-    split_path = paths.get('split_path')
-    base = os.path.basename(full_path)
-    ext = os.path.splitext(base)[1]
-    if ext != '.md':
-        raise InvalidContentTypeError(ext)
-
-    pattern = '^[0-9]{4}-[0-1][0-9]-[0-3][0-9]-+[a-zA-Z]+.*\.md$'
-    is_post = re.match(pattern, base) is not None
-    if is_post is True:
-        obj = Post(parser, full_path, split_path)
-    else:
-        obj = Page(parser, full_path, split_path)
-
-    obj.parser = parser
-    return obj
-
-
 class InvalidContentTypeError(AttributeError):
     pass
 
