@@ -15,6 +15,7 @@ from twisted.internet import reactor
 from stanley.parser import parse_yaml
 from stanley.site import Site
 from stanley.compiler import Jinja2Compiler
+from stanley.config import Config
 from stanley import touch
 
 
@@ -44,15 +45,15 @@ def build(path, less):
     """
     Take the content and build into static html pages
     """
-    s = Site(path)
+    c = Config(path)
+    s = Site(c, parse_yaml)
     # clear existing contents from destination directory
-    for root, dirs, files in os.walk(s.destdir + '/*'):
+    for root, dirs, files in os.walk(c.destdir + '/*'):
         for f in files:
             os.unlink(os.path.join(root, f))
         for d in dirs:
             shutil.rmtree(os.path.join(root, d))
-    c = Jinja2Compiler(s, parse_yaml)
-    return c.compile(less)
+    s.build(less)
 
 
 def server(path):
@@ -65,13 +66,6 @@ def server(path):
     reactor.run()
 
 
-def sitemap():
-    """
-    Generate a google sitemap
-    """
-    pass
-
-
 class Cli(object):
 
     """
@@ -104,7 +98,7 @@ class Cli(object):
 
         parser.add_argument('--less', '-l',
             action='store_true',
-            help='Compile Les files to css (requires that Less is installed')
+            help='Compile LESS files to css (requires that Less is installed')
 
         args = parser.parse_args()
 
@@ -115,10 +109,4 @@ class Cli(object):
         elif args.build is True:
             print '\nBuilding %s' % args.file
             print u'----------------------------------------'
-            (built, total) = build(args.file, args.less)
-            sitemap()
-            for f in built:
-                print '* ' + f
-            print u'----------------------------------------'
-            print 'built %d of %d files' % (len(built), total)
-            print u'----------------------------------------'
+            build(args.file, args.less)
